[![Latest Version](https://img.shields.io/pypi/v/gfys?label=pypi-version&logo=python&style=plastic)](https://pypi.org/project/gfys/)
[![Python Versions](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fdusktreader%2Fgfys%2Fmain%2Fpyproject.toml&style=plastic&logo=python&label=python-versions)](https://www.python.org/)
[![Build Status](https://github.com/dusktreader/gfys/actions/workflows/publish.yml/badge.svg)](https://github.com/dusktreader/gfys/actions/workflows/publish.yml)

![gfys-logo](https://github.com/dusktreader/gfys/blob/main/gfys.png)

_Because `go test` output is f'ing terrible._

I hate reading output from `go test`. So, I made this.

## Super-quick Start

* Requires Python 3.12 or later
* Installed with pip/uv/whatever. Handiest with uv: `uv tool install gfys`

## Documentation

Just run: `gfys --help`

You'll figure it out.
